@@ -51,8 +51,6 @@
 
 #include <boost/date_time/gregorian/gregorian.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
 #include <boost/regex.hpp>
 
 #include <iostream>
@@ -237,6 +235,7 @@ private:
 		content << "Build Time: " << __DATE__ << " " << __TIME__ << " local\r\n";
 		content << m_detail.get_buffer()->get_text() << "\r\n";
 
+/*
 		{
 			Gtk::TreeNodeChildren attachments = m_attachments->children();
 			for(Gtk::TreeNodeChildren::const_iterator attachment = attachments.begin(); attachment != attachments.end(); ++attachment)
@@ -244,10 +243,11 @@ private:
 				if(false == (*attachment).get_value(m_attachment_columns.send))
 					continue;
 
-				const boost::filesystem::path path((*attachment).get_value(m_attachment_columns.file), boost::filesystem::native);
-				content << "File Attachment: " << path.native_file_string() << "\r\n";
+				const k3d::filesystem::path path = k3d::filesystem::native_path((*attachment).get_value(m_attachment_columns.file));
+				content << "File Attachment: " << path.native_console_string() << "\r\n";
 			}
 		}
+*/
 
 		content << "--" << boundary << "\r\n";
 		content << "Content-Disposition: form-data; name=\"submit\"\r\n";
@@ -297,22 +297,23 @@ private:
 
 		bool attachment_error = false;
 
+/*
 		Gtk::TreeNodeChildren attachments = m_attachments->children();
 		for(Gtk::TreeNodeChildren::const_iterator attachment = attachments.begin(); attachment != attachments.end(); ++attachment)
 		{
 			if(false == (*attachment).get_value(m_attachment_columns.send))
 				continue;
 
-			const boost::filesystem::path uncompressed_path =
-				boost::filesystem::path((*attachment).get_value(m_attachment_columns.file), boost::filesystem::native);
+			const k3d::filesystem::path uncompressed_path =
+				k3d::filesystem::native_path((*attachment).get_value(m_attachment_columns.file));
 
-			if(!boost::filesystem::exists(uncompressed_path))
+			if(!k3d::filesystem::exists(uncompressed_path))
 			{
-				k3d::log() << error << "Cannot attach nonexistent file [" << uncompressed_path.native_file_string() << "]" << std::endl;
+				k3d::log() << error << "Cannot attach nonexistent file [" << uncompressed_path.native_console_string() << "]" << std::endl;
 				continue;
 			}
 
-			const boost::filesystem::path compressed_path = k3d::system::generate_temp_file();
+			const k3d::filesystem::path compressed_path = k3d::system::generate_temp_file();
 			{
 				k3d::filesystem::ifstream uncompressed_file(uncompressed_path);
 				k3d::filesystem::ogzstream compressed_file(compressed_path);
@@ -348,7 +349,7 @@ private:
 
 			k3d::filesystem::ifstream compressed_file(compressed_path);
 			content << "--" << boundary << "\r\n";
-			content << "Content-Disposition: form-data; name=\"input_file\"; filename=\"" << uncompressed_path.leaf() << ".gz\"\r\n";
+			content << "Content-Disposition: form-data; name=\"input_file\"; filename=\"" << uncompressed_path.leaf().raw() << ".gz\"\r\n";
 			content << "Content-Type: application/octet-stream\r\n";
 			content << "\r\n";
 			content << compressed_file.rdbuf();
@@ -401,6 +402,7 @@ private:
 				attachment_error = true;
 			}
 		}
+*/
 
 		if(attachment_error)
 		{
@@ -493,7 +495,7 @@ void setup_logging(const std::string& ProcessName)
 /// Program main
 int main(int argc, char* argv[])
 {
-	const std::string program_name = boost::filesystem::path(argv[0], boost::filesystem::native).leaf();
+	const std::string program_name = k3d::filesystem::native_path(k3d::ustring::from_utf8(std::string(argv[0]))).leaf().raw();
 
 #ifdef K3D_HAVE_NLS
 	setlocale(LC_ALL, "");
