@@ -26,8 +26,6 @@
 
 #include "iunknown.h"
 
-namespace boost { namespace filesystem { class path; } }
-
 namespace k3d
 {
 
@@ -36,7 +34,7 @@ class istill_render_engine :
 	public virtual k3d::iunknown
 {
 public:
-	virtual bool render_frame(const boost::filesystem::path& OutputImage, const bool ViewCompletedImage) = 0;
+	virtual bool render_frame(const filesystem::path& OutputImage, const bool ViewCompletedImage) = 0;
 
 protected:
 	istill_render_engine() {}
