@@ -24,13 +24,13 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include <boost/filesystem/path.hpp>
+#include "path.h"
 
 namespace k3d
 {
 
 /// Returns the absolute path to the shared-data directory
-const boost::filesystem::path share_path();
+const filesystem::path share_path();
 
 } // namespace k3d
 
